EmitterConfiguration class Initialization and configuration

Configuration of the event emitter.

Annotations

Constructors

EmitterConfiguration({bool? serverAnonymisation})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverAnonymisation → bool?
Adds a request header ('SP-anonymous') that prevents the event collector from adding a network_userid cookie, as well as anonymising the user's IP address. Setting serverAnonymisation also enables (and overrides) TrackerConfiguration.userAnonymisation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited