NetworkRequestConfiguration class

Annotations

Constructors

NetworkRequestConfiguration({required List blocklist, required List<CollectAttr> collectattr, required bool enabled})
const
NetworkRequestConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

blocklist → List
final
collectattr → List<CollectAttr>
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited