Conviva class Getting started Initialization and configuration

Main interface for the package mainly used to initialize trackers and track events.

Constructors

Conviva()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createConvivaTracker({required String appName, required String customerKey, NetworkConfiguration? networkConfig, TrackerConfiguration? trackerConfig, SubjectConfiguration? subjectConfig, GdprConfiguration? gdprConfig, EmitterConfiguration? emitterConfig, NetworkRequestConfiguration? networkRequestConfig, TraceparentConfiguration? traceparentConfig}) → Future<ConvivaTracker>
Creates a new tracker instance with the given unique namespace.
getSessionId({required String tracker}) → Future<String?>
Returns the identifier (string UUIDv4) for the session.
getSessionIndex({required String tracker}) → Future<int?>
Returns the index (number) of the current session for this user.
getSessionUserId({required String tracker}) → Future<String?>
Returns the identifier (string UUIDv4) for the user of the session.
getTraceparentId({required String targetUrl}) → Future<String>
Returns traceparent info.
setUserId(String? userId, {required String tracker}) → Future<void>
Sets the business user ID to the string for the tracker namespace.
track(Event event, {required String tracker, List<SelfDescribing>? contexts}) → Future<void>
Tracks the given event using the specified tracker namespace and with optional context entities.
trackCustomEvent(String? name, String? data, {required String tracker}) → Future<void>
Sets the business user ID to the string for the tracker namespace.