ConvivaObserver class

Route observer that tracks ScreenView or PageViewEvent events when the currently active ModalRoute changes.

See the documentation in ConvivaTracker.getObserver for a more in-depth guide.

Inheritance

Constructors

ConvivaObserver({required ConvivaTracker tracker, ScreenNameExtractor nameExtractor = defaultNameExtractor})

Properties

hashCode → int
The hash code for this object.
no setterinherited
nameExtractor → ScreenNameExtractor
final
The navigator that the observer is observing, if any.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracker → ConvivaTracker
final

Methods

debugObservingRoute(ModalRoute route) → bool
Whether this observer is managing changes for the specified route.
inherited
didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
override
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
override
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
inherited
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
override
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(RouteAware routeAware, ModalRoute route) → void
Subscribe routeAware to be informed about changes to route.
inherited
toString() → String
A string representation of this object.
inherited
unsubscribe(RouteAware routeAware) → void
Unsubscribe routeAware.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited