ConvivaTrackerPluginWeb class

Constructors

ConvivaTrackerPluginWeb()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleMethodCall(MethodCall call) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCreateConvivaTracker(MethodCall call) → void
onCreateTracker(MethodCall call) → void
onGetSessionId(MethodCall call) → String?
onGetSessionIndex(MethodCall call) → int?
onGetSessionUserId(MethodCall call) → String?
onSetUserId(MethodCall call) → void
onTrackButtonClick(MethodCall call) → void
onTrackConsentGranted(MethodCall call) → void
onTrackConsentWithdrawn(MethodCall call) → void
onTrackCustomEvent(MethodCall call) → void
onTrackPageView(MethodCall call) → void
onTrackScreenView(MethodCall call) → void
onTrackSelfDescribing(MethodCall call) → void
onTrackStructured(MethodCall call) → void
onTrackTiming(MethodCall call) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void