ButtonClick class Adding data to your events Tracking events

Event to track button click within the application.

Implemented types
Annotations

Constructors

ButtonClick({String? elementType, String? elementId, String? elementName, String? elementClasses, String? elementText, String? elementValue})
const

Properties

elementClasses → String?
The class of the element.
final
elementId → String?
The identifier of the element.
final
elementName → String?
The name of the element.
final
elementText → String?
The text of the elemant.
final
elementType → String?
The type of the element.
final
elementValue → String?
The value of the element.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

endpoint() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited