NetworkData class

Inheritance

Constructors

NetworkData({required String? targetUrl, required String? method, required String contentType, required String? rqb, required Map<String, dynamic>? rqh, required int requestTimestamp, required int responseTimestamp, String? responseStatusText, required String? rsb, required int responseStatusCode, required Map<String, dynamic>? rsh})

Properties

contentType → String
final
hashCode → int
The hash code for this object.
no setterinherited
method → String?
final
requestTimestamp → int
final
responseStatusCode → int
final
responseStatusText → String?
final
responseTimestamp → int
final
rqb → String?
final
rqh → Map<String, dynamic>?
final
rsb → String?
final
rsh → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetUrl → String?
final

Methods

endpoint() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited