ScreenView class Adding data to your events Tracking events

Event to track user viewing a screen within the application.

Implemented types
Annotations

Constructors

ScreenView({required String name, required String id, String? type, String? previousName, String? previousType, String? previousId, String? transitionType})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The id (UUID v4) of screen that was viewed.
final
name → String
The name of the screen viewed.
final
previousId → String?
The id (UUID v4) of the previous screen that was viewed.
final
previousName → String?
The name of the previous screen that was viewed.
final
previousType → String?
The type of screen that was viewed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionType → String?
The type of transition that led to the screen being viewed.
final
type → String?
The type of screen that was viewed.
final

Methods

endpoint() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited