Structured class Adding data to your events Tracking events

Event to capture custom consumer interactions without the need to define a custom schema.

Implemented types
Annotations

Constructors

Structured({required String category, required String action, String? label, String? property, double? value})
const

Properties

action → String
Defines the type of user interaction for the web object.
final
category → String
Name you for the group of objects you want to track e.g. "media", "ecomm".
final
hashCode → int
The hash code for this object.
no setterinherited
label → String?
Identifies the specific object being actioned.
final
property → String?
Describes the object or the action performed on it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double?
Quantifies or further describes the user action.
final

Methods

endpoint() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited