Timing class Adding data to your events Tracking events

Event used to track user timing events such as how long resources take to load.

Implemented types
Annotations

Constructors

Timing({required String category, required String variable, required int timing, String? label})
const

Properties

category → String
Defines the timing category.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String?
An optional string to further identify the timing event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timing → int
Represents the time.
final
variable → String
Defines the timing variable measured.
final

Methods

endpoint() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited