ConvivaTracker class Getting started

Instance of an initialized Conviva tracker identified by a namespace.

Constructors

ConvivaTracker({required Configuration configuration})
const

Properties

configuration → Configuration
Tracker configuration.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → Future<String?>
Returns the identifier (string UUIDv4) for the session.
no setter
sessionIndex → Future<int?>
Returns the index (number) of the current session for this user.
no setter
sessionUserId → Future<String?>
Returns the identifier (string UUIDv4) for the user of the session.
no setter
tracksPageViews → bool
Namespace that identifies the tracker. Returns true if current platform is Web and PageViewEvent tracking is enabled in trackerConfig.webActivityTracking configuration.
no setter

Methods

getObserver({ScreenNameExtractor nameExtractor = defaultNameExtractor}) → ConvivaObserver
Returns a ConvivaObserver for automatically tracking PageViewEvent and ScreenView events from a navigator when the currently active ModalRoute of the navigator changes.
getTraceparentId({required String targetUrl}) → Future<String>
Returns the traceparent id for the targetUrl.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserId(String? userId) → Future<void>
Sets the business user ID to the string.
toString() → String
A string representation of this object.
inherited
track(Event event, {List<SelfDescribing>? contexts}) → Future<void>
Tracks the given event with optional context entities.
trackCustomEvent(String? name, String? data) → Future<void>
Sets the business user ID to the string.

Operators

operator ==(Object other) → bool
The equality operator.
inherited